pub struct Cache { /* private fields */ }Expand description
Wraps RemoteBlockDeviceSync providing a simple LRU cache and trait implementations for std::io::{Read, Seek, Write}. This is unlikely to be performant; the implementation is single threaded. The cache works by dividing up a VMO into BLOCK_COUNT blocks of BLOCK_SIZE bytes, and maintaining mappings from device offsets to offsets in the VMO.
Implementations
Sourceimpl Cache
impl Cache
Sourcepub fn new(device: RemoteBlockClientSync) -> Result<Self, Error>
pub fn new(device: RemoteBlockClientSync) -> Result<Self, Error>
Returns a new Cache wrapping the given RemoteBlockClientSync.
Sourcepub fn read_at(&mut self, buf: &mut [u8], offset: u64) -> Result<(), Error>
pub fn read_at(&mut self, buf: &mut [u8], offset: u64) -> Result<(), Error>
Reads at |offset| into |buf|.
Sourcepub fn write_at(&mut self, buf: &[u8], offset: u64) -> Result<(), Error>
pub fn write_at(&mut self, buf: &[u8], offset: u64) -> Result<(), Error>
Writes from |buf| to |offset|.
Sourcepub fn device(&self) -> &RemoteBlockClientSync
pub fn device(&self) -> &RemoteBlockClientSync
Returns a reference to the underlying device Can be used for additional control, like instructing the device to flush any written data
pub fn flush_device(&self) -> Result<(), Error>